Installation
============

Conda and pip
-------------

Papylio can be installed through conda.

.. code-block::

   conda install papylio -c conda-forge

or through using pip

.. code-block::

   pip install papylio

where it is recommended to make a separate virtual environment or conda environment for `papylio`.

Anaconda Navigator
------------------
Papylio can also be installed through the Anaconda Navigator gui.

1. Download and install `Anaconda Navigator`_. (e.g. v2.6.3)
2. Create a new environment

   - Go to the `Environments` tab
   - Click `Create`
   - Enter the environment name, e.g. `papylio`
   - Select Python with version 3.9.x
   - Click `Create`
   - Select the `papylio` environment.

3. Add the `conda-forge` channel.

   - Click `Channels`
   - Click `Add`
   - Type `conda-forge` and hit `Enter`.
   - Click `Update channels`.

4. Install papylio

   - Change `Installed` to `Not installed`
   - Search for `papylio` in the `Search Packages` search box.
   - Click the small square on the left side of `papylio`.
   - Click `Apply`


.. _Anaconda Navigator: https://www.anaconda.com/products/navigator